@@ -15,7 +15,6 @@ from wapitiCore.language.vulnerability import INFO_LEVEL, HIGH_LEVEL, MEDIUM_LEV
 from wapitiCore.net.crawler import AsyncCrawler
 from wapitiCore.net.classes import CrawlerConfiguration
 from wapitiCore.net import Request
-from wapitiCore.attack.attack import VULN, ADDITION
 
 
 @pytest.mark.asyncio
@@ -400,10 +399,9 @@ async def test_multi_detection():
     fixture_folder = Path(__file__).parent.parent / "data" / "wapp"
 
     # Let's mock wapiti-scanner/nvd-web-cves repository
-    wordpress_json_xz_url = (
-        "https://github.com/wapiti-scanner/nvd-web-cves/releases/download/"
-        "nvd-web-cves-20240808/wordpress.json.xz"
-    )
+    nvd_cve_xz_base = "https://github.com/wapiti-scanner/nvd-web-cves/releases/download/nvd-web-cves-20240808/"
+    wordpress_json_xz_url = nvd_cve_xz_base + "wordpress.json.xz"
+    apache_json_xz_url = nvd_cve_xz_base + "apache.json.xz"
 
     respx.get("https://api.github.com/repos/wapiti-scanner/nvd-web-cves/releases/latest").mock(
         return_value=httpx.Response(
@@ -414,6 +412,10 @@ async def test_multi_detection():
                         "name": "wordpress.json.xz",
                         "browser_download_url": wordpress_json_xz_url,
                     },
+                    {
+                        "name": "apache.json.xz",
+                        "browser_download_url": apache_json_xz_url,
+                    },
                 ]
             }
         )
@@ -422,12 +424,19 @@ async def test_multi_detection():
     respx.get(wordpress_json_xz_url).mock(
         return_value=httpx.Response(
             status_code=200,
-            content=lzma.compress((fixture_folder / "cve.json").open("rb").read())
+            content=lzma.compress((fixture_folder / "wordpress_cve.json").open("rb").read())
+        )
+    )
+
+    respx.get(apache_json_xz_url).mock(
+        return_value=httpx.Response(
+            status_code=200,
+            content=lzma.compress((fixture_folder / "apache_cve.json").open("rb").read())
         )
     )
 
     # Now let's mock wapiti-scanner/wappalyzerfork. Wappalyzer files are split over the 1st character of software names.
-    for letter, filename in [("m", "mysql.json"), ("p", "php.json"), ("w", "wordpress.json")]:
+    for letter, filename in [("a", "apache.json"), ("m", "mysql.json"), ("p", "php.json"), ("w", "wordpress.json")]:
         respx.get(
             f"https://raw.githubusercontent.com/wapiti-scanner/wappalyzerfork/main/src/technologies/{letter}.json"
         ).mock(
@@ -473,7 +482,10 @@ async def test_multi_detection():
             <strong><pre>    * <----- vous &ecirc;tes ici</pre></strong> \
             <script type=\"text/javascript\" src=\"https://perdu.com/wp-includes/js/wp-embed.min.js\" ></script> \
             </body></html>",
-            headers={"link": "<http://perdu.com/wp-json/>; rel=\"https://api.w.org/\""}
+            headers={
+                "link": "<http://perdu.com/wp-json/>; rel=\"https://api.w.org/\"",
+                "Server": "Apache/2.4.29 (Ubuntu)"
+            }
         )
     )
 
@@ -494,53 +506,54 @@ async def test_multi_detection():
             await module.attack(request)
 
             # Findings:
+            # - Fingerprint for Apache
+            # - Fingerprint for Apache version
+            # - Vulnerable software for Apache
             # - Fingerprint for Wordpress as a technology
             # - Fingerprint for Wordpress as a framework
             # - Fingerprint for PHP that was deduced from Wordpress
             # - Fingerprint for MySQL that was deduced from Wordpress
             # - Vulnerable software for Wordpress
-            assert persister.add_payload.call_count == 5
+            assert persister.add_payload.call_count == 8
             assert {parameters[1]["category"] for parameters in persister.add_payload.call_args_list} == {
                 "Fingerprint web application framework",
+                "Fingerprint web server",
                 "Fingerprint web technology",
                 "Vulnerable software"
             }
 
             persister.add_payload.assert_any_call(
-                request_id=-1,
-                payload_type=VULN,
+                payload_type="vulnerability",
                 module="wapp",
                 category="Fingerprint web application framework",
                 level=INFO_LEVEL,
                 request=request,
-                parameter="",
+                parameter=None,
                 info='{"name": "WordPress", "versions": ["5.6.1"], "cpe": "cpe:2.3:a:wordpress:wordpress:*:*:*:*:*:*:*:*", "categories": ["CMS", "Blogs"], "groups": ["Content"]}',
                 wstg=["WSTG-INFO-08"],
                 response=ANY,
             )
 
             persister.add_payload.assert_any_call(
-                request_id=-1,
-                payload_type=ADDITION,
+                payload_type="additional",
                 module="wapp",
                 category="Fingerprint web technology",
                 level=INFO_LEVEL,
                 request=request,
-                parameter="",
+                parameter=None,
                 info='{"name": "PHP", "versions": [], "cpe": "cpe:2.3:a:php:php:*:*:*:*:*:*:*:*", "categories": ["Programming languages"], "groups": ["Web development"]}',
                 wstg=['WSTG-INFO-02', 'WSTG-INFO-08'],
                 response=ANY,
             )
 
             persister.add_payload.assert_any_call(
-                request_id=-1,
-                payload_type=VULN,
+                payload_type="vulnerability",
                 module="wapp",
                 category="Vulnerable software",
                 # Level is high as we use the most recent CVSS format which is CVSS 3.1 here. Score is 8.8.
                 level=HIGH_LEVEL,
                 request=request,
-                parameter="",
+                parameter=None,
                 info=(
                     "wordpress CVE-2022-21664: WordPress is a free and open-source content management system written "
                     "in PHP and paired with a MariaDB database. Due to lack of proper sanitization in one of the "
