@@ -9,8 +9,10 @@ import httpx
 import pytest
 
 from wapitiCore.report import GENERATORS
+from wapitiCore.report.htmlreportgenerator import level_to_css_class
 from wapitiCore.net import Request
 from wapitiCore.definitions import additionals, anomalies, vulnerabilities, flatten_references
+from wapitiCore.language.vulnerability import CRITICAL_LEVEL, HIGH_LEVEL, MEDIUM_LEVEL, LOW_LEVEL, INFO_LEVEL
 from wapitiCore.net.sql_persister import Response
 
 DATA_DIR = os.path.join(os.path.dirname(__file__), "data")
@@ -102,7 +104,7 @@ def test_reports(report_format):
         temp_obj = tempfile.TemporaryDirectory()
         output = temp_obj.name
     else:
-        # Use a temporary file that is not deleted on close
+        # Use a temporary file not deleted on close
         temp_file = tempfile.NamedTemporaryFile(delete=False, mode='w', encoding='utf-8')
         output = temp_file.name
         temp_file.close()
@@ -206,7 +208,7 @@ def test_detailed_reports(report_format, level):
         temp_obj = tempfile.TemporaryDirectory()
         output = temp_obj.name
     else:
-        # Use a temporary file that is not deleted on close
+        # Use a temporary file not deleted on close
         temp_file = tempfile.NamedTemporaryFile(delete=False, mode='w', encoding='utf-8')
         output = temp_file.name
         temp_file.close()
@@ -232,3 +234,12 @@ def test_detailed_reports(report_format, level):
 
     if report_format != "html":
         os.remove(output)
+
+
+def test_level_to_css_class():
+    assert level_to_css_class(CRITICAL_LEVEL) == "severity-critical"
+    assert level_to_css_class(HIGH_LEVEL) == "severity-high"
+    assert level_to_css_class(MEDIUM_LEVEL) == "severity-medium"
+    assert level_to_css_class(LOW_LEVEL) == "severity-low"
+    assert level_to_css_class(INFO_LEVEL) == "severity-info"
+    assert level_to_css_class(999) == ""
