@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # This file is part of the Wapiti project (https://wapiti-scanner.github.io)
-# Copyright (C) 2020-2023 Nicolas Surribas
+# Copyright (C) 2020-2025 Nicolas Surribas
 # Copyright (C) 2020-2024 Cyberwatch
 #
 # This program is free software; you can redistribute it and/or modify
@@ -23,13 +23,12 @@ import shutil
 import string
 from typing import Dict, Tuple, Optional, List, AsyncIterator
 import re
-from urllib.parse import urlparse, quote_plus
+from urllib.parse import quote_plus
 
-from aiocache import cached
 from httpx import RequestError
-
-from wapiti_arsenic import get_session, browsers, services
-from wapiti_arsenic.errors import JavascriptError, UnknownError, ArsenicError
+# pylint: disable=protected-access
+from playwright._impl._errors import TargetClosedError
+from playwright.async_api import async_playwright, Error as PlaywrightError
 
 from wapitiCore.attack.cve.checker import (
     CVEChecker, cvss_score_to_wapiti_level, CVE_DIRECTORY, SUPPORTED_SOFTWARES, is_cve_supported_software
@@ -55,21 +54,23 @@ BULK_SIZE = 50
 VERSION_REGEX = re.compile(r"^\d[\w.-]*$")
 
 SCRIPT = (
-    "wapiti_results = {};\n"
-    "for (var js_tech in wapiti_tests) {\n"
-    "  js_tech_results = [];\n"
-    "  for (var i in wapiti_tests[js_tech]) {\n"
-    "    try {\n"
-    "      js_tech_results.push([String(eval(wapiti_tests[js_tech][i])), wapiti_tests[js_tech][i]]);\n"
-    "    } catch(wapiti_error) {\n"
-    "      continue;\n"
+    "(wapiti_tests) => {\n"
+    "  let wapiti_results = {};\n"
+    "  for (var js_tech in wapiti_tests) {\n"
+    "    let js_tech_results = [];\n"
+    "    for (let i = 0; i < wapiti_tests[js_tech].length; i++) {\n"
+    "      try {\n"
+    "        js_tech_results.push([String(eval(wapiti_tests[js_tech][i])), wapiti_tests[js_tech][i]]);\n"
+    "      } catch(wapiti_error) {\n"
+    "        continue;\n"
+    "      }\n"
+    "    }\n"
+    "    if (js_tech_results.length) {\n"
+    "      wapiti_results[js_tech] = js_tech_results;\n"
     "    }\n"
     "  }\n"
-    "  if (js_tech_results.length) {\n"
-    "    wapiti_results[js_tech] = js_tech_results;\n"
-    "  }\n"
-    "}\n"
-    "return wapiti_results;\n"
+    "  return wapiti_results;\n"
+    "}"
 )
 
 
@@ -159,15 +160,16 @@ class ModuleWapp(Attack):
             os.makedirs(self.user_config_dir)
 
         self._cve_checker = CVEChecker(self.user_config_dir)
+        self._nvd_release_data: Optional[dict] = None
 
     async def copy_files_to_conf(self, files_to_copy: List[str]):
         """
         This function copies wapp DB files specified as arguments to the config directory.
         """
         for source_file in files_to_copy:
-            # Check if file exists before attempting to copy
+            # Check if a file exists before attempting to copy
             if not os.path.isfile(source_file):
-                logging.error(f"Warning: File {source_file} does not exist, skipping.")
+                logging.error("Warning: File %s does not exist, skipping.", source_file)
                 continue
 
             # Construct the destination file path using the filename
@@ -175,9 +177,9 @@ class ModuleWapp(Attack):
 
             try:
                 shutil.copy(source_file, destination_file)
-                logging.info(f"Copied {source_file} to {destination_file}")
+                logging.info("Copied %s to %s", source_file, destination_file)
             except shutil.Error as err:
-                logging.error(f"Error copying {source_file}: {err}")
+                logging.error("Error copying %s: %s", source_file, err)
 
     async def update(self):
         await self.update_nvd()
@@ -240,12 +242,12 @@ class ModuleWapp(Attack):
                     wapp_groups_url
                 )
             except RequestError as e:
-                logging.error(f"RequestError occurred: {e}")
+                logging.error("RequestError occurred: %s", e)
                 raise
             except IOError:
                 logging.error("Error downloading wapp database.")
             except ValueError as e:
-                logging.error(f"Value error: {e}")
+                logging.error("Value error: %s", e)
                 raise
 
     async def must_attack(self, request: Request, response: Optional[Response] = None):
@@ -259,7 +261,6 @@ class ModuleWapp(Attack):
 
     async def attack(self, request: Request, response: Optional[Response] = None):
         self.finished = True
-        request_to_root = Request(request.url)
         categories_file_path = os.path.join(self.user_config_dir, self.WAPP_CATEGORIES)
         groups_file_path = os.path.join(self.user_config_dir, self.WAPP_GROUPS)
         technologies_file_path = os.path.join(self.user_config_dir, self.WAPP_TECHNOLOGIES)
@@ -279,7 +280,7 @@ class ModuleWapp(Attack):
             logging.error(exception)
             return
 
-        detected_applications, response = await self._detect_applications(request.url, application_data)
+        detected_applications, sent_request, response = await self._detect_applications(request.url, application_data)
 
         if detected_applications:
             log_blue("---")
@@ -300,7 +301,7 @@ class ModuleWapp(Attack):
             log_blue("")
             await self.add_info(
                 finding_class=SoftwareNameDisclosureFinding,
-                request=request_to_root,
+                request=sent_request,
                 info=json.dumps(detected_applications[application_name]),
                 response=response
             )
@@ -309,14 +310,14 @@ class ModuleWapp(Attack):
                 if "Web servers" in categories:
                     await self.add_info(
                         finding_class=WebServerVersionDisclosureFinding,
-                        request=request_to_root,
+                        request=sent_request,
                         info=json.dumps(detected_applications[application_name]),
                         response=response
                     )
                 else:
                     await self.add_info(
                         finding_class=SoftwareVersionDisclosureFinding,
-                        request=request_to_root,
+                        request=sent_request,
                         info=json.dumps(detected_applications[application_name]),
                         response=response
                     )
@@ -335,7 +336,7 @@ class ModuleWapp(Attack):
                                 finding_class=VulnerableSoftwareFinding,
                                 level=severity,
                                 info=message,
-                                request=request_to_root,
+                                request=sent_request,
                                 response=response
                             )
 
@@ -359,7 +360,7 @@ class ModuleWapp(Attack):
             self,
             url: str,
             application_data: ApplicationData
-    ) -> Tuple[Dict, Optional[Response]]:
+    ) -> Tuple[Dict, Request, Optional[Response]]:
         detected_applications = {}
         response = None
 
@@ -381,7 +382,7 @@ class ModuleWapp(Attack):
             wappalyzer = Wappalyzer(application_data, response, headless_results)
             detected_applications.update(wappalyzer.detect())
 
-        return detected_applications, response
+        return detected_applications, request, response
 
     async def _dump_url_content_to_file(self, url: str, file_path: str):
         request = Request(url)
@@ -392,7 +393,7 @@ class ModuleWapp(Attack):
             raise
 
         if response.status != 200:
-            logging.error(f"Error: Non-200 status code for {url}")
+            logging.error("Error: Non-200 status code for %s", url)
             return
 
         if not _is_valid_json(response):
@@ -442,10 +443,10 @@ class ModuleWapp(Attack):
                 self._dump_url_content_to_file(groups_url, groups_file_path)
             )
         except RequestError as req_error:
-            logging.error(f"Caught a RequestError: {req_error}")
+            logging.error("Caught a RequestError: %s", req_error)
             raise
         except ValueError as value_error:
-            logging.error(f"Caught a ValueError: {value_error}")
+            logging.error("Caught a ValueError: %s", value_error)
             raise
 
     async def _verify_wapp_database(
@@ -469,45 +470,46 @@ class ModuleWapp(Attack):
     async def _detect_applications_headless(self, url: str) -> dict:
         proxy_settings = None
         if self.crawler_configuration.proxy:
-            proxy = urlparse(self.crawler_configuration.proxy).netloc
-            proxy_settings = {
-                "proxyType": 'manual',
-                "httpProxy": proxy,
-                "sslProxy": proxy
-            }
-
-        service = services.Geckodriver(log_file=os.devnull)
-        browser = browsers.Firefox(
-            proxy=proxy_settings,
-            acceptInsecureCerts=True,
-            **{
-                "moz:firefoxOptions": {
-                    "prefs": {
-                        "network.proxy.allow_hijacking_localhost": True,
-                        "devtools.jsonview.enabled": False,
-                    },
-                    "args": ["-headless"]
-                }
-            }
-        )
+            proxy_settings = {"server": self.crawler_configuration.proxy}
 
         technologies_file_path = os.path.join(self.user_config_dir, self.WAPP_TECHNOLOGIES)
         final_results = {}
 
-        with open(technologies_file_path, encoding="utf-8") as fd:
-            data = json.load(fd)
-            try:
-                async with get_session(service, browser) as headless_client:
-                    await headless_client.get(url, timeout=self.crawler_configuration.timeout)
-                    await asyncio.sleep(5)
+        try:
+            with open(technologies_file_path, encoding="utf-8") as fd:
+                data = json.load(fd)
+        except FileNotFoundError:
+            return {}
+
+        try:
+            async with async_playwright() as p:
+                browser = await p.firefox.launch(
+                    headless=True,
+                    proxy=proxy_settings,
+                    firefox_user_prefs={
+                        "network.proxy.allow_hijacking_localhost": True,
+                        "devtools.jsonview.enabled": False,
+                    }
+                )
+                context = await browser.new_context(ignore_https_errors=True)
+                page = await context.new_page()
+
+                try:
+                    await page.goto(
+                        url,
+                        timeout=self.crawler_configuration.timeout * 1000,
+                        wait_until="domcontentloaded"
+                    )
+                    await page.wait_for_timeout(5000)
                     for tests in get_tests(data):
-                        script = f"wapiti_tests = {json.dumps(tests)};\n" + SCRIPT
                         try:
-                            results = await headless_client.execute_script(script)
+                            results = await page.evaluate(SCRIPT, tests)
                             for software, version_and_js in results.items():
                                 waiting_version = []
                                 validated = False
                                 for version, js in version_and_js:
+                                    if js is None:
+                                        continue
                                     expected_format = data[software]["js"][js]
                                     if version == "undefined":
                                         continue
@@ -529,26 +531,40 @@ class ModuleWapp(Attack):
                                             final_results[software] = [version]
                                             break
                                     # Other cases seems to be some kind of false positives
-                                if validated and waiting_version and not final_results[software]:
+                                if validated and waiting_version and not final_results.get(software):
                                     final_results[software] = waiting_version
-                        except (JavascriptError, UnknownError) as exception:
+                        except PlaywrightError as exception:
+                            if isinstance(exception, TargetClosedError):
+                                break
                             logging.exception(exception)
                             continue
+                finally:
+                    await browser.close()
 
-            except (ArsenicError, FileNotFoundError, asyncio.TimeoutError):
-                # Geckodriver may be missing, etc
-                pass
+        except (PlaywrightError, FileNotFoundError, asyncio.TimeoutError) as exception:
+            if isinstance(exception, TargetClosedError):
+                return {}
+
+            # Playwright browser may be missing, etc
+            logging.warning(
+                "Could not run headless browser. "
+                "Make sure playwright is installed (`pip install playwright`) "
+                "and browsers are installed (`playwright install`)."
+            )
 
         return final_results
 
-    @cached()
-    async def get_nvd_release_data(self):
+    async def get_nvd_release_data(self) -> dict:
+        if self._nvd_release_data is not None:
+            return self._nvd_release_data
+
         release_url = "https://api.github.com/repos/wapiti-scanner/nvd-web-cves/releases/latest"
 
         # Create and send the request to get the latest release
         release_request = Request(release_url)
         release_response = await self.crawler.async_send(release_request)
-        return release_response.json
+        self._nvd_release_data = release_response.json
+        return self._nvd_release_data
 
     async def download_latest_release_asset(self, software_name: str, dest_folder: str) -> bool:
         # Ensure the destination folder exists
@@ -564,13 +580,13 @@ class ModuleWapp(Attack):
             # The response is cached as we don't want to repeat the same query for each received software name
             latest_release = await self.get_nvd_release_data()
         except RequestError as exception:
-            logging.error(f"Could not fetch wapiti-scanner/nvd-web-cves CVE index for {software_name}: {exception}")
+            logging.error("Could not fetch wapiti-scanner/nvd-web-cves CVE index for %s: %s", software_name, exception)
             return False
 
         # Find the asset related to the software_name
         asset = next((a for a in latest_release.get("assets", []) if file_name in a["name"]), None)
         if asset is None:
-            logging.error(f"No CVE data found for {software_name} on wapiti-scanner/nvd-web-cves")
+            logging.error("No CVE data found for %s on wapiti-scanner/nvd-web-cves", software_name)
             return False
 
         # Download the asset
