@@ -20,9 +20,8 @@
 import json
 import os
 from collections import namedtuple
-from typing import AsyncIterator, Iterable, List, Optional, Sequence, Tuple
+from typing import AsyncIterator, Iterable, List, Optional, Sequence, Tuple, Dict, Any
 
-from aiocache import cached
 import httpx
 from sqlalchemy import (Boolean, Column, ForeignKey, Integer, MetaData,
                         PickleType, String, Table, Text, LargeBinary, and_,
@@ -178,12 +177,16 @@ class SqlPersister:
             ))
         self.root_url = root_url
 
-    @cached()
     async def get_root_url(self) -> str:
+        if self.root_url:
+            return self.root_url
+
         statement = select(self.scan_infos).where(self.scan_infos.c.key == "root_url").limit(1)
         async with self._engine.begin() as conn:
             result = await conn.execute(statement)
-            return result.fetchone().value
+            value = result.fetchone().value
+            self.root_url = value
+            return value
 
     async def set_to_browse(self, to_browse: Sequence[Request]):
         await self.save_requests([(request, None) for request in to_browse])
@@ -523,7 +526,7 @@ class SqlPersister:
         async for request, response in self._get_paths(path=path, method="POST", crawled=True, module=attack_module):
             yield request, response
 
-    async def get_all_paths(self) -> List:
+    async def get_crawled_paths(self) -> List[Dict[str, Any]]:
         statement = select(
             self.paths,
             self.responses.c.status_code,
@@ -550,19 +553,11 @@ class SqlPersister:
                 },
                 "response": {
                     "status_code": row.status_code,
-                    "body": row.body,
+                    "body": row.body.decode("utf-8", errors="replace"),
                     "headers": [[key, value] for key, value in (row.response_headers or {}).items()]
                 },
             } for row in result.fetchall()]
 
-    async def get_necessary_paths(self) -> List:
-        requests = []
-        async for request, response in self._get_paths(crawled=False):
-            requests.append({"request": {"url": request.url, "method": request.method,
-                                         "post_params": request.post_params,
-                                         "status_code": response.status if response else None}})
-        return requests
-
     async def count_paths(self) -> int:
         statement = select(sql_count(self.paths.c.path_id)).where(~self.paths.c.evil)
         async with self._engine.begin() as conn:
